@@ -38,6 +38,20 @@ class Table(Parented):
             tr.add_tc()
         return _Row(tr, self)
 
+    @property
+    def autofit(self):
+        """
+        |True| if column widths can be automatically adjusted to improve the
+        fit of cell contents. |False| if table layout is fixed. Column widths
+        are adjusted in either case if total column width exceeds page width.
+        Read/write boolean.
+        """
+        return self._tblPr.autofit
+
+    @autofit.setter
+    def autofit(self, value):
+        self._tblPr.autofit = value
+
     def cell(self, row_idx, col_idx):
         """
         Return |_Cell| instance correponding to table cell at *row_idx*,
@@ -107,6 +121,17 @@ class _Cell(Parented):
         r = p.add_r()
         r.text = text
 
+    @property
+    def width(self):
+        """
+        The width of this cell in EMU, or |None| if no explicit width is set.
+        """
+        return self._tc.width
+
+    @width.setter
+    def width(self, value):
+        self._tc.width = value
+
 
 class _Column(Parented):
     """
