@@ -8,6 +8,7 @@ from __future__ import absolute_import, print_function, unicode_literals
 
 import pytest
 
+from docx.shared import Inches
 from docx.table import (
     _Cell, _Column, _ColumnCells, _Columns, _Row, _RowCells, _Rows, Table
 )
@@ -60,6 +61,15 @@ class DescribeTable(object):
         table.style = style_name
         assert table._tbl.xml == expected_xml
 
+    def it_knows_whether_it_should_autofit(self, autofit_get_fixture):
+        table, expected_value = autofit_get_fixture
+        assert table.autofit is expected_value
+
+    def it_can_change_its_autofit_setting(self, autofit_set_fixture):
+        table, new_value, expected_xml = autofit_set_fixture
+        table.autofit = new_value
+        assert table._tbl.xml == expected_xml
+
     # fixtures -------------------------------------------------------
 
     @pytest.fixture
@@ -76,6 +86,35 @@ class DescribeTable(object):
         expected_xml = _tbl_bldr(rows=2, cols=2).xml()
         return table, expected_xml
 
+    @pytest.fixture(params=[
+        ('w:tbl/w:tblPr',                             True),
+        ('w:tbl/w:tblPr/w:tblLayout',                 True),
+        ('w:tbl/w:tblPr/w:tblLayout{w:type=autofit}', True),
+        ('w:tbl/w:tblPr/w:tblLayout{w:type=fixed}',   False),
+    ])
+    def autofit_get_fixture(self, request):
+        tbl_cxml, expected_autofit = request.param
+        table = Table(element(tbl_cxml), None)
+        return table, expected_autofit
+
+    @pytest.fixture(params=[
+        ('w:tbl/w:tblPr', True,
+         'w:tbl/w:tblPr/w:tblLayout{w:type=autofit}'),
+        ('w:tbl/w:tblPr', False,
+         'w:tbl/w:tblPr/w:tblLayout{w:type=fixed}'),
+        ('w:tbl/w:tblPr', None,
+         'w:tbl/w:tblPr/w:tblLayout{w:type=fixed}'),
+        ('w:tbl/w:tblPr/w:tblLayout{w:type=fixed}', True,
+         'w:tbl/w:tblPr/w:tblLayout{w:type=autofit}'),
+        ('w:tbl/w:tblPr/w:tblLayout{w:type=autofit}', False,
+         'w:tbl/w:tblPr/w:tblLayout{w:type=fixed}'),
+    ])
+    def autofit_set_fixture(self, request):
+        tbl_cxml, new_value, expected_tbl_cxml = request.param
+        table = Table(element(tbl_cxml), None)
+        expected_xml = xml(expected_tbl_cxml)
+        return table, new_value, expected_xml
+
     @pytest.fixture(params=[
         ('w:tbl/w:tblPr', None),
         ('w:tbl/w:tblPr/w:tblStyle{w:val=foobar}', 'foobar'),
@@ -130,8 +169,22 @@ class Describe_Cell(object):
         cell.text = text
         assert cell._tc.xml == expected_xml
 
+    def it_knows_its_width_in_EMU(self, width_get_fixture):
+        cell, expected_width = width_get_fixture
+        assert cell.width == expected_width
+
+    def it_can_change_its_width(self, width_set_fixture):
+        cell, value, expected_xml = width_set_fixture
+        cell.width = value
+        assert cell.width == value
+        assert cell._tc.xml == expected_xml
+
     # fixtures -------------------------------------------------------
 
+    @pytest.fixture
+    def paragraphs_fixture(self):
+        return _Cell(element('w:tc/(w:p, w:p)'), None)
+
     @pytest.fixture(params=[
         ('w:tc/w:p', 'foobar',
          'w:tc/w:p/w:r/w:t"foobar"'),
@@ -146,9 +199,28 @@ class Describe_Cell(object):
         expected_xml = xml(expected_cxml)
         return cell, new_text, expected_xml
 
-    @pytest.fixture
-    def paragraphs_fixture(self):
-        return _Cell(element('w:tc/(w:p, w:p)'), None)
+    @pytest.fixture(params=[
+        ('w:tc',                                   None),
+        ('w:tc/w:tcPr',                            None),
+        ('w:tc/w:tcPr/w:tcW{w:w=25%,w:type=pct}',  None),
+        ('w:tc/w:tcPr/w:tcW{w:w=1440,w:type=dxa}', 914400),
+    ])
+    def width_get_fixture(self, request):
+        tc_cxml, expected_width = request.param
+        cell = _Cell(element(tc_cxml), None)
+        return cell, expected_width
+
+    @pytest.fixture(params=[
+        ('w:tc', Inches(1),
+         'w:tc/w:tcPr/w:tcW{w:w=1440,w:type=dxa}'),
+        ('w:tc/w:tcPr/w:tcW{w:w=25%,w:type=pct}', Inches(2),
+         'w:tc/w:tcPr/w:tcW{w:w=2880,w:type=dxa}'),
+    ])
+    def width_set_fixture(self, request):
+        tc_cxml, new_value, expected_cxml = request.param
+        cell = _Cell(element(tc_cxml), None)
+        expected_xml = xml(expected_cxml)
+        return cell, new_value, expected_xml
 
 
 class Describe_Column(object):
